@@ -2,7 +2,8 @@ __all__ = [
     "MOVEConfig",
     "EncodeDataConfig",
     "AnalyzeLatentConfig",
-    "TuneModelConfig",
+    "TuneModelReconstructionConfig",
+    "TuneModelStabilityConfig",
     "IdentifyAssociationsConfig",
     "IdentifyAssociationsBayesConfig",
     "IdentifyAssociationsTTestConfig",
@@ -27,6 +28,10 @@ class InputConfig:
     name: str
     weight: int = 1
 
+@dataclass
+class ContinuousInputConfig(InputConfig):
+    scale: bool = True
+
 
 @dataclass
 class DataConfig:
@@ -35,7 +40,7 @@ class DataConfig:
     results_path: str = MISSING
     sample_names: str = MISSING
     categorical_inputs: list[InputConfig] = MISSING
-    continuous_inputs: list[InputConfig] = MISSING
+    continuous_inputs: list[ContinuousInputConfig] = MISSING
     categorical_names: list[str] = MISSING
     continuous_names: list[str] = MISSING
     categorical_weights: list[int] = MISSING
@@ -104,6 +109,20 @@ class TuneModelConfig(TaskConfig):
     ...
 
 
+@dataclass
+class TuneModelStabilityConfig(TuneModelConfig):
+    """Configure the "tune model" task."""
+
+    num_refits: int = MISSING
+
+
+@dataclass
+class TuneModelReconstructionConfig(TuneModelConfig):
+    """Configure the "tune model" task."""
+
+    ...
+
+
 @dataclass
 class AnalyzeLatentConfig(TaskConfig):
     """Configure the "analyze latents" task.
@@ -194,8 +213,14 @@ cs.store(
 )
 cs.store(
     group="task",
-    name="tune_model_schema",
-    node=TuneModelConfig,
+    name="tune_model_reconstruction_schema",
+    node=TuneModelReconstructionConfig,
+)
+
+cs.store(
+    group="task",
+    name="tune_model_stability_schema",
+    node=TuneModelStabilityConfig,
 )
 cs.store(
     group="task",
